summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/twisted/avahi/tubes/request-muc-tubes.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/twisted/avahi/tubes/request-muc-tubes.py b/tests/twisted/avahi/tubes/request-muc-tubes.py
index f5921c0c..ce54ab35 100644
--- a/tests/twisted/avahi/tubes/request-muc-tubes.py
+++ b/tests/twisted/avahi/tubes/request-muc-tubes.py
@@ -9,7 +9,7 @@ import avahitest
from twisted.words.xish import domish
from saluttest import exec_test, wait_for_contact_list
-from servicetest import call_async, EventPattern, wrap_channel
+from servicetest import call_async, EventPattern, wrap_channel, pretty
from constants import *
def test(q, bus, conn):
@@ -23,11 +23,11 @@ def test(q, bus, conn):
# announced so they won't interfere with the muc ones announces.
wait_for_contact_list(q, conn)
# check if we can request roomlist channels
properties = conn.Properties.GetAll(CONN_IFACE_REQUESTS)
- assert ({CHANNEL_TYPE: CHANNEL_TYPE_TUBES,
+ assert ({CHANNEL_TYPE: CHANNEL_TYPE_STREAM_TUBE,
TARGET_HANDLE_TYPE: HT_ROOM},
- [TARGET_HANDLE, TARGET_ID],
+ [TARGET_HANDLE, TARGET_ID, STREAM_TUBE_SERVICE],
) in properties.get('RequestableChannelClasses'),\
properties['RequestableChannelClasses']
@@ -23,11 +23,11 @@ def test(q, bus, conn):
# announced so they won't interfere with the muc ones announces.
wait_for_contact_list(q, conn)
- # check if we can request roomlist channels
+ # check if we can request tube channels
properties = conn.Properties.GetAll(CONN_IFACE_REQUESTS)